@@ -32,7 +32,7 @@ sub post_process {
 
     if( $resp->is_success ) {
         my $user = $self->_stringify_json_booleans(
-            JSON::Any->new->decode( $resp->content )
+            JSON::MaybeXS::decode_json( $resp->content )
         );
         $session_data->{facebook}{user_info} = $user;
         $session->write('oauth', $session_data);
